import com.robertpenner.graphics.XColor;

/**
* The ColorClip class extends the MovieClip class adding a collection of utilities
* that allows for more intuitive color manipulation.
* 
* @author Robert Penner (AS 1.0)
*  2002 Robert Penner
* http://www.robertpenner.com
* 
* @author Mark Walters (AS 2.0)
*  2006 DigitalFlipbook
*  2006 DigitalFlipbook
* http://www.digitalflipbook.com
* 
* @version	1.0
* 
* @since	ActionScript 2.0; Flash Player 6
*/
class com.robertpenner.display.ColorClip extends MovieClip {
	
	/*
	* CLASS PROPERTIES
	*/
	private static var initialized:Boolean = false;
	private static var mixins:ColorClip = new ColorClip();
	private static var mixInProps:Array = ["setRGB", "getRGB", "setRGBStr", "getRGBStr", "setRGB2", "getRGB2", "setColorTransform", "getColorTransform", "resetColor", "setBrightness", "getBrightness", "setBrightOffset", "getBrightOffset", "setTint", "getTint", "setTint2", "getTint2", "setTintOffset", "getTintOffset", "setTintOffset2", "getTintOffset2", "invertColor", "setNegativeColor", "getNegativeColor", "setRed", "getRed", "setGreen", "getGreen", "setBlue", "getBlue", "setRedPercent", "getRedPercent", "setGreenPercent", "getGreenPercent", "setBluePercent", "getBluePercent", "setRedOffset", "getRedOffset", "setGreenOffset", "getGreenOffset", "setBlueOffset", "getBlueOffset"];
	
	
	/*
	* *********************************************************
	* CONSTRUCTOR
	* *********************************************************
	*
	*/
	function ColorClip () {
		super();
	}
	
	
	/*
	* *********************************************************
	* PRIVATE METHODS
	* *********************************************************
	* 
	*/
	private function createProp (obj:Object, propName:String, setter:Boolean):Void {
		var p = (propName.charAt(0) == "_") ? propName.charAt(1).toUpperCase() + propName.substr(2) : propName.charAt(0).toUpperCase() + propName.substr(1);
		//--CUSTOM--
		if (p == "Rgb") {
			p = "RGB";
		} else if (p == "RgbStr") {
			p = "RGBStr";
		}
		//--CUSTOM--
		var s = null;
		var g = function(Void) {
			return this["get" + p]();
		}
		if (setter) {
			s = function(val) {
				this["set" + p](val);
			}
		}
		obj.addProperty(propName, g, s);
	}
	
	
	/*
	* *********************************************************
	* PUBLIC METHODS
	* *********************************************************
	* 
	*/
	
	/**
	* Decorates all MovieClips with the methods of the XColor class.
	* 
	* @usage
	* <pre><code>
	* com.robertpenner.display.ColorClip.init();
	* </code></pre>
	*/
	public static function init ():Void {
		if (com.robertpenner.display.ColorClip.initialized) { return; };
		com.robertpenner.display.ColorClip.initialized = true;
		com.robertpenner.display.ColorClip.mixin (MovieClip.prototype);
	}
	
	/**
	* Decorates a particular MovieClip instance with the methods of the XColor class.
	* 
	* @param	obj		The object to mix in.
	* 
	* @usage
	* <pre><code>
	* com.robertpenner.display.ColorClip.mixin(my_mc);
	* </code></pre>
	*/
	public static function mixin (obj:Object):Void {
		var m:Array = mixInProps;
		var l:Number = m.length;

		for (var i:Number = 0; i<l; i++) {
			obj[m[i]] = com.robertpenner.display.ColorClip.mixins[m[i]];
			_global.ASSetPropFlags(obj, m[i], 1);
		}
		
		com.robertpenner.display.ColorClip.mixins.createProp(obj, "rgb", true);
		_global.ASSetPropFlags(obj, "rgb", 1);
		com.robertpenner.display.ColorClip.mixins.createProp(obj, "rgbStr", true);
		_global.ASSetPropFlags(obj, "rgbStr", 1);
		com.robertpenner.display.ColorClip.mixins.createProp(obj, "brightness", true);
		_global.ASSetPropFlags(obj, "brightness", 1);
		com.robertpenner.display.ColorClip.mixins.createProp(obj, "brightOffset", true);
		_global.ASSetPropFlags(obj, "brightOffset", 1);
		com.robertpenner.display.ColorClip.mixins.createProp(obj, "negativeColor", true);
		_global.ASSetPropFlags(obj, "negativeColor", 1);
		com.robertpenner.display.ColorClip.mixins.createProp(obj, "red", true);
		_global.ASSetPropFlags(obj, "red", 1);
		com.robertpenner.display.ColorClip.mixins.createProp(obj, "green", true);
		_global.ASSetPropFlags(obj, "green", 1);
		com.robertpenner.display.ColorClip.mixins.createProp(obj, "blue", true);
		_global.ASSetPropFlags(obj, "blue", 1);
		com.robertpenner.display.ColorClip.mixins.createProp(obj, "redPercent", true);
		_global.ASSetPropFlags(obj, "redPercent", 1);
		com.robertpenner.display.ColorClip.mixins.createProp(obj, "greenPercent", true);
		_global.ASSetPropFlags(obj, "greenPercent", 1);
		com.robertpenner.display.ColorClip.mixins.createProp(obj, "bluePercent", true);
		_global.ASSetPropFlags(obj, "bluePercent", 1);
		com.robertpenner.display.ColorClip.mixins.createProp(obj, "redOffset", true);
		_global.ASSetPropFlags(obj, "redOffset", 1);
		com.robertpenner.display.ColorClip.mixins.createProp(obj, "greenOffset", true);
		_global.ASSetPropFlags(obj, "greenOffset", 1);
		com.robertpenner.display.ColorClip.mixins.createProp(obj, "blueOffset", true);
		_global.ASSetPropFlags(obj, "blueOffset", 1);
	}
	
	/**
	* Specifies an RGB color for a ColorClip object.
	* 
	* @param	col		The hexadecimal or RGB color to be set.
	* 
	* @usage
	* <pre><code>
	* my_mc.setRGB(0x0000FF);
	* </code></pre>
	*/
	public function setRGB (col:Number):Void {
		(new XColor(this)).setRGB(col);
	}
	
	/**
	* Returns the R+G+B combination currently in use by the ColorClip object.
	* 
	* @return	A number that represents the RGB numeric value for the color specified.
	* 
	* @usage
	* <pre><code>
	* trace (my_mc.getRGB());
	* </code></pre>
	*/
	public function getRGB ():Number {
		return (new XColor(this)).getRGB();
	}
	
	/**
	* Specifies an RGB color for a ColorClip object using a string hexadecimal value.
	* 
	* @param	hexStr	The string hexadecimal color to be set.
	* 
	* @usage
	* <pre><code>
	* my_mc.setRGBStr("#FFFF00");
	* </code></pre>
	*/
	public function setRGBStr (hexStr:String):Void {
		(new XColor(this)).setRGBStr(hexStr);
	}
	
	/**
	* Returns the R+G+B combination currently in use by the ColorClip object as a string hexadecimal value.
	* 
	* @return	The string hexadecimal color.
	* 
	* @usage
	* <pre><code>
	* trace (my_mc.getRGBStr());
	* </code></pre>
	*/
	public function getRGBStr ():String {
		return (new XColor(this)).getRGBStr();
	}
	
	/**
	* Specifies an RGB color for a ColorClip object using individual red, green, and blue values.
	* 
	* @param	r		The red color value.
	* @param	g		The green color value.
	* @param	b		The blue color value.
	* 
	* @usage
	* <pre><code>
	* my_mc.setRGB2(255, 0, 255);
	* </code></pre>
	*/
	public function setRGB2 (r:Number, g:Number, b:Number):Void {
		(new XColor(this)).setRGB2(r, g, b);
	}
	
	/**
	* Returns the R+G+B values currently in use by the ColorClip object as individual red, green, and blue values.
	* 
	* @return	The RBG value object with r, g, and b properties.
	* 
	* @usage
	* <pre><code>
	* var rgb:Object = my_mc.getRGB2();
	* trace (rgb.r);
	* trace (rgb.g);
	* trace (rgb.b);
	* </code></pre>
	*/
	public function getRGB2 ():Object {
		return (new XColor(this)).getRGB2();
	}
	
	/**
	* Sets color transform information for a ColorClip object.
	* 
	* @param	trans	The transform object to be set.
	* 
	* @usage
	* <pre><code>
	* my_mc.setColorTransform({ ra: 50, rb: 244, ga: 25, gb: 112, ba: 75, bb: 90, aa: 40, ab: 70});
	* </code></pre>
	*/
	public function setColorTransform (trans:Object):Void {
		(new XColor(this)).setTransform(trans);
	}
	
	/**
	* Returns the transform value set by the last color.
	* 
	* @return	An object whose properties contain the current offset and percentage values for the specified color.
	* 
	* @usage
	* <pre><code>
	* var trans:Object = my_mc.getColorTransform();
	* trace (trans.ra);
	* trace (trans.ga);
	* trace (trans.ba);
	* </code></pre>
	*/
	public function getColorTransform ():Object {
		return (new XColor(this)).getTransform();
	}
	
	/**
	* Sets the color transform for a ColorClip object to its default values.
	* 
	* @usage
	* <pre><code>
	* my_mc.setRGB(0x0000FF);
	* my_mc.resetColor();
	* </code></pre>
	*/
	public function resetColor ():Void {
		(new XColor(this)).reset();
	}
	
	/**
	* Specifies the brightness of a ColorClip object.
	* 
	* @param	bright	A percentage value between -100 and 100. Positive values brighten the color. and negative values darken it.
	* 
	* @usage
	* <pre><code>
	* my_mc.setBrightness(50);
	* </code></pre>
	*/
	public function setBrightness (bright:Number):Void {
		(new XColor(this)).setBrightness(bright);
	}
	
	/**
	* Returns the brightness of a ColorClip object.
	* 
	* @return	The brightness value.
	* 
	* @usage
	* <pre><code>
	* my_mc.setBrightness(50);
	* trace (my_mc.getBrightness());
	* </code></pre>
	*/
	public function getBrightness ():Number {
		return (new XColor(this)).getBrightness();
	}
	
	/**
	* Pushes a ColorClip object towards black or white by an absolute amount.
	* 
	* @param	offset	A number between -255 and 255. Positive values push colors towards white; negative values towards black.
	* 
	* @usage
	* <pre><code>
	* my_mc.setBrightOffset(140);
	* </code></pre>
	*/
	public function setBrightOffset (offset:Number):Void {
		(new XColor(this)).setBrightOffset(offset);
	}
	
	/**
	* Returns the brightness offset value of a ColorClip object.
	* 
	* @return	The brightness offset value.
	* 
	* @usage
	* <pre><code>
	* my_mc.setBrightOffset(140);
	* trace (my_mc.getBrightOffset());
	* </code></pre>
	*/
	public function getBrightOffset ():Number {
		return (new XColor(this)).getBrightOffset();
	}
	
	/**
	* Tints a ColorClip object with a color according to a certain percentage.
	* 
	* @param	r		The red color value.
	* @param	g		The green color value.
	* @param	b		The blue color value.
	* @param	percent	The tint percentage.
	* 
	* @usage
	* <pre><code>
	* my_mc.setTint(0, 0, 128, 50);
	* </code></pre>
	*/
	public function setTint (r:Number, g:Number, b:Number, percent:Number):Void {
		(new XColor(this)).setTint(r, g, b, percent);
	}
	
	/**
	* Returns the tint of a ColorClip object.
	* 
	* @return	The tint value object with r, g, b, and percent properties.
	* 
	* @usage
	* <pre><code>
	* my_mc.setTint(0, 0, 128, 50);
	* var tint:Object = my_mc.getTint();
	* trace (tint.r);
	* trace (tint.g);
	* trace (tint.b);
	* trace (tint.percent);
	* </code></pre>
	*/
	public function getTint ():Object {
		return (new XColor(this)).getTint();
	}
	
	/**
	* Tints a ColorClip object with a color according to a certain percentage.
	* 
	* @param	rgb		The rgb value.
	* @param	percent	The tint percentage.
	* 
	* @usage
	* <pre><code>
	* my_mc.setTint2(0x0000FF, 100);
	* </code></pre>
	*/
	public function setTint2 (rgb:Number, percent:Number):Void {
		(new XColor(this)).setTint2(rgb, percent);
	}
	
	/**
	* Returns the tint of a ColorClip object.
	* 
	* @return	The tint value object with rgb and percent properties.
	* 
	* @usage
	* <pre><code>
	* my_mc.setTint2(0x0000FF, 100);
	* var tint:Object = my_mc.getTint2();
	* trace (tint.rgb);
	* trace (tint.percent);
	* </code></pre>
	*/
	public function getTint2 ():Object {
		return (new XColor(this)).getTint2();
	}
	
	/**
	* Tints a ColorClip object with a color according to red, green, and blue values.
	* 
	* @param	r		The red color value.
	* @param	g		The green color value.
	* @param	b		The blue color value.
	* 
	* @usage
	* <pre><code>
	* my_mc.setTintOffset(0, 0, 128);
	* </code></pre>
	*/
	public function setTintOffset (r:Number, g:Number, b:Number):Void {
		(new XColor(this)).setTintOffset(r, g, b);
	}
	
	/**
	* Returns the tint offset of a ColorClip object.
	* 
	* @return	The tint offset value object with r, g, and b properties.
	* 
	* @usage
	* <pre><code>
	* my_mc.setTintOffset(0, 0, 128);
	* var tint:Object = my_mc.getTintOffset();
	* trace (tint.r);
	* trace (tint.g);
	* trace (tint.b);
	* </code></pre>
	*/
	public function getTintOffset ():Object {
		return (new XColor(this)).getTintOffset();
	}
	
	/**
	* Tints a ColorClip object with a color according to an rgb value.
	* 
	* @param	rgb		The rgb value.
	* 
	* @usage
	* <pre><code>
	* my_mc.setTintOffset2(0x000080);
	* </code></pre>
	*/
	public function setTintOffset2 (rgb:Number):Void {
		(new XColor(this)).setTintOffset2(rgb);
	}
	
	/**
	* Returns the tint offset of a ColorClip object.
	* 
	* @return	The tint offset value object with an rgb properties.
	* 
	* @usage
	* <pre><code>
	* my_mc.setTintOffset2(0x000080);
	* trace (my_mc.getTintOffset2());
	* </code></pre>
	*/
	public function getTintOffset2 ():Number {
		return (new XColor(this)).getTintOffset2();
	}
	
	/**
	* Performs a straightforward color inversion.
	* 
	* @usage
	* <pre><code>
	* my_mc.invertColor();
	* </code></pre>
	*/
	public function invertColor ():Void {
		(new XColor(this)).invert();
	}
	
	/**
	* Inverts a ColorClip object by a certain percentage.
	* 
	* @param	percent	The negative percentage.
	* 
	* @usage
	* <pre><code>
	* my_mc.setNegativeColor(60);
	* </code></pre>
	*/
	public function setNegativeColor (percent:Number):Void {
		(new XColor(this)).setNegative(percent);
	}
	
	/**
	* Returns the negative percentage of a ColorClip object.
	* 
	* @return	The negative percentage.
	* 
	* @usage
	* <pre><code>
	* my_mc.setNegativeColor(60);
	* trace (my_mc.getNegativeColor());
	* </code></pre>
	*/
	public function getNegativeColor ():Number {
		return (new XColor(this)).getNegative();
	}
	
	/**
	* Specifies a red color value for a ColorClip object.
	* 
	* @param	amount	The red color value.
	* 
	* @usage
	* <pre><code>
	* my_mc.setRed(128);
	* </code></pre>
	*/
	public function setRed (amount:Number):Void {
		(new XColor(this)).setRed(amount);
	}
	
	/**
	* Returns the red color value of a ColorClip object.
	* 
	* @return	The red color value.
	* 
	* @usage
	* <pre><code>
	* my_mc.setRed(128);
	* trace (my_mc.getRed());
	* </code></pre>
	*/
	public function getRed ():Number {
		return (new XColor(this)).getRed();
	}
	
	/**
	* Specifies a green color value for a ColorClip object.
	* 
	* @param	amount	The green color value.
	* 
	* @usage
	* <pre><code>
	* my_mc.setGreen(128);
	* </code></pre>
	*/
	public function setGreen (amount:Number):Void {
		(new XColor(this)).setGreen(amount);
	}
	
	/**
	* Returns the green color value of a ColorClip object.
	* 
	* @return	The green color value.
	* 
	* @usage
	* <pre><code>
	* my_mc.setGreen(128);
	* trace (my_mc.getGreen());
	* </code></pre>
	*/
	public function getGreen ():Number {
		return (new XColor(this)).getGreen();
	}
	
	/**
	* Specifies a blue color value for a ColorClip object.
	* 
	* @param	amount	The blue color value.
	* 
	* @usage
	* <pre><code>
	* my_mc.setBlue(128);
	* </code></pre>
	*/
	public function setBlue (amount:Number):Void {
		(new XColor(this)).setBlue(amount);
	}
	
	/**
	* Returns the blue color value of a ColorClip object.
	* 
	* @return	The blue color value.
	* 
	* @usage
	* <pre><code>
	* my_mc.setBlue(128);
	* trace (my_mc.getBlue());
	* </code></pre>
	*/
	public function getBlue ():Number {
		return (new XColor(this)).getBlue();
	}
	
	/**
	* Specifies a red percentage value for a ColorClip object.
	* 
	* @param	percent	The red percentage value.
	* 
	* @usage
	* <pre><code>
	* my_mc.setRedPercent(50);
	* </code></pre>
	*/
	public function setRedPercent (percent:Number):Void {
		(new XColor(this)).setRedPercent(percent);
	}
	
	/**
	* Returns the red percentage value of a ColorClip object.
	* 
	* @return	The red percentage value.
	* 
	* @usage
	* <pre><code>
	* my_mc.setRedPercent(50);
	* trace (my_mc.getRedPercent());
	* </code></pre>
	*/
	public function getRedPercent ():Number {
		return (new XColor(this)).getRedPercent();
	}
	
	/**
	* Specifies a green percentage value for a ColorClip object.
	* 
	* @param	percent	The green percentage value.
	* 
	* @usage
	* <pre><code>
	* my_mc.setGreenPercent(50);
	* </code></pre>
	*/
	public function setGreenPercent (percent:Number):Void {
		(new XColor(this)).setGreenPercent(percent);
	}
	
	/**
	* Returns the green percentage value of a ColorClip object.
	* 
	* @return	The green percentage value.
	* 
	* @usage
	* <pre><code>
	* my_mc.setGreenPercent(50);
	* trace (my_mc.getGreenPercent());
	* </code></pre>
	*/
	public function getGreenPercent ():Number {
		return (new XColor(this)).getGreenPercent();
	}
	
	/**
	* Specifies a blue percentage value for a ColorClip object.
	* 
	* @param	percent	The blue percentage value.
	* 
	* @usage
	* <pre><code>
	* my_mc.setBluePercent(50);
	* </code></pre>
	*/
	public function setBluePercent (percent:Number):Void {
		(new XColor(this)).setBluePercent(percent);
	}
	
	/**
	* Returns the blue percentage value of a ColorClip object.
	* 
	* @return	The blue percentage value.
	* 
	* @usage
	* <pre><code>
	* my_mc.setBluePercent(50);
	* trace (my_mc.getBluePercent());
	* </code></pre>
	*/
	public function getBluePercent ():Number {
		return (new XColor(this)).getBluePercent();
	}
	
	/**
	* Specifies a red offset value for a ColorClip object.
	* 
	* @param	percent	The red offset value.
	* 
	* @usage
	* <pre><code>
	* my_mc.setRedOffset(-128);
	* </code></pre>
	*/
	public function setRedOffset (offset:Number):Void {
		(new XColor(this)).setRedOffset(offset);
	}
	
	/**
	* Returns the red offset value of a ColorClip object.
	* 
	* @return	The red offset value.
	* 
	* @usage
	* <pre><code>
	* my_mc.setRedOffset(-128);
	* trace (my_mc.getRedOffset());
	* </code></pre>
	*/
	public function getRedOffset ():Number {
		return (new XColor(this)).getRedOffset();
	}
	
	/**
	* Specifies a green offset value for a ColorClip object.
	* 
	* @param	percent	The green offset value.
	* 
	* @usage
	* <pre><code>
	* my_mc.setGreenOffset(-128);
	* </code></pre>
	*/
	public function setGreenOffset (offset:Number):Void {
		(new XColor(this)).setGreenOffset(offset);
	}
	
	/**
	* Returns the green offset value of a ColorClip object.
	* 
	* @return	The green offset value.
	* 
	* @usage
	* <pre><code>
	* my_mc.setGreenOffset(-128);
	* trace (my_mc.getGreenOffset());
	* </code></pre>
	*/
	public function getGreenOffset ():Number {
		return (new XColor(this)).getGreenOffset();
	}
	
	/**
	* Specifies a blue offset value for a ColorClip object.
	* 
	* @param	percent	The blue offset value.
	* 
	* @usage
	* <pre><code>
	* my_mc.setBlueOffset(-128);
	* </code></pre>
	*/
	public function setBlueOffset (offset:Number):Void {
		(new XColor(this)).setBlueOffset(offset);
	}
	
	/**
	* Returns the blue offset value of a ColorClip object.
	* 
	* @return	The blue offset value.
	* 
	* @usage
	* <pre><code>
	* my_mc.setBlueOffset(-128);
	* trace (my_mc.getBlueOffset());
	* </code></pre>
	*/
	public function getBlueOffset ():Number {
		return (new XColor(this)).getBlueOffset();
	}
	
	
	/*
	* *********************************************************
	* GETTERS/SETTERS
	* *********************************************************
	* 
	*/
	
	/**
	* The rgb property of the ColorClip.
	* 
	* @usage
	* <pre><code>
	* trace (my_mc.rgb);
	* </code></pre>
	*/
	public function get rgb ():Number {
		return this.getRGB();
	}
	public function set rgb (col:Number):Void {
		this.setRGB(col);
	}
	
	/**
	* The rgbStr property of the ColorClip.
	* 
	* @usage
	* <pre><code>
	* trace (my_mc.rgbStr);
	* </code></pre>
	*/
	public function get rgbStr ():String {
		return this.getRGBStr();
	}
	public function set rgbStr (hexStr:String):Void {
		this.setRGBStr(hexStr);
	}
	
	/**
	* The brightness property of the ColorClip.
	* 
	* @usage
	* <pre><code>
	* trace (my_mc.brightness);
	* </code></pre>
	*/
	public function get brightness ():Number {
		return this.getBrightness();
	}
	public function set brightness (bright:Number):Void {
		this.setBrightness(bright);
	}
	
	/**
	* The brightOffset property of the ColorClip.
	* 
	* @usage
	* <pre><code>
	* trace (my_mc.brightOffset);
	* </code></pre>
	*/
	public function get brightOffset ():Number {
		return this.getBrightOffset();
	}
	public function set brightOffset (offset:Number):Void {
		this.setBrightOffset(offset);
	}
	
	/**
	* The negativeColor property of the ColorClip.
	* 
	* @usage
	* <pre><code>
	* trace (my_mc.negativeColor);
	* </code></pre>
	*/
	public function get negativeColor ():Number {
		return this.getNegativeColor();
	}
	public function set negativeColor (percent:Number):Void {
		this.setNegativeColor(percent);
	}
	
	/**
	* The red property of the ColorClip.
	* 
	* @usage
	* <pre><code>
	* trace (my_mc.red);
	* </code></pre>
	*/
	public function get red ():Number {
		return this.getRed();
	}
	public function set red (amount:Number):Void {
		this.setRed(amount);
	}
	
	/**
	* The green property of the ColorClip.
	* 
	* @usage
	* <pre><code>
	* trace (my_mc.green);
	* </code></pre>
	*/
	public function get green ():Number {
		return this.getGreen();
	}
	public function set green (amount:Number):Void {
		this.setGreen(amount);
	}
	
	/**
	* The blue property of the ColorClip.
	* 
	* @usage
	* <pre><code>
	* trace (my_mc.blue);
	* </code></pre>
	*/
	public function get blue ():Number {
		return this.getBlue();
	}
	public function set blue (amount:Number):Void {
		this.setBlue(amount);
	}
	
	/**
	* The redPercent property of the ColorClip.
	* 
	* @usage
	* <pre><code>
	* trace (my_mc.redPercent);
	* </code></pre>
	*/
	public function get redPercent ():Number {
		return this.getRedPercent();
	}
	public function set redPercent (percent:Number):Void {
		this.setRedPercent(percent);
	}
	
	/**
	* The greenPercent property of the ColorClip.
	* 
	* @usage
	* <pre><code>
	* trace (my_mc.greenPercent);
	* </code></pre>
	*/
	public function get greenPercent ():Number {
		return this.getGreenPercent();
	}
	public function set greenPercent (percent:Number):Void {
		this.setGreenPercent(percent);
	}
	
	/**
	* The bluePercent property of the ColorClip.
	* 
	* @usage
	* <pre><code>
	* trace (my_mc.bluePercent);
	* </code></pre>
	*/
	public function get bluePercent ():Number {
		return this.getBluePercent();
	}
	public function set bluePercent (percent:Number):Void {
		this.setBluePercent(percent);
	}
	
	/**
	* The redOffset property of the ColorClip.
	* 
	* @usage
	* <pre><code>
	* trace (my_mc.redOffset);
	* </code></pre>
	*/
	public function get redOffset ():Number {
		return this.getRedOffset();
	}
	public function set redOffset (offset:Number):Void {
		this.setRedOffset(offset);
	}
	
	/**
	* The greenOffset property of the ColorClip.
	* 
	* @usage
	* <pre><code>
	* trace (my_mc.greenOffset);
	* </code></pre>
	*/
	public function get greenOffset ():Number {
		return this.getGreenOffset();
	}
	public function set greenOffset (offset:Number):Void {
		this.setGreenOffset(offset);
	}
	
	/**
	* The blueOffset property of the ColorClip.
	* 
	* @usage
	* <pre><code>
	* trace (my_mc.blueOffset);
	* </code></pre>
	*/
	public function get blueOffset ():Number {
		return this.getBlueOffset();
	}
	public function set blueOffset (offset:Number):Void {
		this.setBlueOffset(offset);
	}
	
}
