﻿import com.robertpenner.utils.ColorUtil;

/**
* The XColor class extends the Color class adding a collection of utilities
* that allows for more intuitive color manipulation.
* 
* @author Robert Penner (AS 1.0)
* © 2002 Robert Penner
* http://www.robertpenner.com
* 
* @author Mark Walters (AS 2.0)
* © 2006 DigitalFlipbook
* © 2006 DigitalFlipbook
* http://www.digitalflipbook.com
* 
* @version	1.0
* 
* @since	ActionScript 2.0; Flash Player 6
*/
class com.robertpenner.graphics.XColor extends Color {	
	
	/*
	* *********************************************************
	* CONSTRUCTOR
	* *********************************************************
	*
	*/
	function XColor (target:Object) {
		super(target);
	}
	
	
	/*
	* *********************************************************
	* PUBLIC METHODS
	* *********************************************************
	* 
	*/
	
	/**
	* Specifies an RGB color for an XColor object.
	* 
	* @param	col	The hexadecimal or RGB color to be set.
	* 
	* @usage
	* <pre><code>
	* var my_color:XColor = new XColor(my_mc);
	* my_color.setRGB(0xFFFF00);
	* </code></pre>
	*/
	public function setRGB (col:Number):Void {
		super.setRGB(col);
	}
	
	/**
	* Returns the R+G+B combination currently in use by the XColor object.
	* 
	* @return	A number that represents the RGB numeric value for the color specified.
	* 
	* @usage
	* <pre><code>
	* var my_color:XColor = new XColor(my_mc);
	* trace (my_color.getRGB());
	* </code></pre>
	*/
	public function getRGB ():Number {
		return super.getRGB();
	}
	
	/**
	* Specifies an RGB color for an XColor object using a string hexadecimal value.
	* 
	* @param	hexStr	The string hexadecimal color to be set.
	* 
	* @usage
	* <pre><code>
	* var my_color:XColor = new XColor(my_mc);
	* my_color.setRGBStr("#FFFF00");
	* </code></pre>
	*/
	public function setRGBStr (hexStr:String):Void {
		ColorUtil.setRGBStr(this, hexStr);
	}
	
	/**
	* Returns the R+G+B combination currently in use by the XColor object as a string hexadecimal value.
	* 
	* @return	The string hexadecimal color.
	* 
	* @usage
	* <pre><code>
	* var my_color:XColor = new XColor(my_mc);
	* trace (my_color.getRGBStr());
	* </code></pre>
	*/
	public function getRGBStr ():String {
		return ColorUtil.getRGBStr(this);
	}
	
	/**
	* Specifies an RGB color for an XColor object using individual red, green, and blue values.
	* 
	* @param	r		The red color value.
	* @param	g		The green color value.
	* @param	b		The blue color value.
	* 
	* @usage
	* <pre><code>
	* var my_color:XColor = new XColor(my_mc);
	* my_color.setRGB2(255, 0, 255);
	* </code></pre>
	*/
	public function setRGB2 (r:Number, g:Number, b:Number):Void {
		ColorUtil.setRGB2(this, r, g, b);
	}
	
	/**
	* Returns the R+G+B values currently in use by the XColor object as individual red, green, and blue values.
	* 
	* @return	The RBG value object with r, g, and b properties.
	* 
	* @usage
	* <pre><code>
	* var my_color:XColor = new XColor(my_mc);
	* my_color.setRGB2(255, 0, 255);
	* var rgb:Object = my_color.getRGB2();
	* trace (rgb.r);
	* trace (rgb.g);
	* trace (rgb.b);
	* </code></pre>
	*/
	public function getRGB2 ():Object {
		return ColorUtil.getRGB2(this);
	}
	
	/**
	* Sets color transform information for an XColor object.
	* 
	* @param	trans	An object that must have the following properties that specify color transform values: ra, rb, ga, gb, ba, bb, aa, ab.
	* 
	* @usage
	* <pre><code>
	* var my_color:XColor = new XColor(my_mc);
	* var my_trans:Object = {ra:50, rb:244, ga:40, gb:112, ba:12, bb:90, aa:40, ab:70};
	* my_color.setTransform(my_trans);
	* </code></pre>
	*/
	public function setTransform (trans:Object):Void {
		super.setTransform(trans);
	}
	
	/**
	* Returns the transform value set by the last XColor.setTransform() call.
	* 
	* @return	An object whose properties contain the current offset and percentage values for the specified color.
	* 
	* @usage
	* <pre><code>
	* var my_color:XColor = new XColor(my_mc);
	* var trans:Object = my_color.getTransform();
	* trace ([trans.ra, trans.rb, trans.ga, trans.gb, trans.ba, trans.bb, trans.aa, trans.ab]);
	* </code></pre>
	*/
	public function getTransform ():Object {
		return super.getTransform();
	}
	
	/**
	* Sets the color transform for an XColor object to its default values.
	* 
	* @usage
	* <pre><code>
	* var my_color:XColor = new XColor(my_mc);
	* my_color.setRGB(0x0000FF);
	* my_color.reset();
	* </code></pre>
	*/
	public function reset ():Void {
		ColorUtil.reset(this);
	}
	
	/**
	* Specifies the brightness of an XColor object.
	* 
	* @param	bright	A percentage value between -100 and 100. Positive values brighten the color. and negative values darken it.
	* 
	* @usage
	* <pre><code>
	* var my_color:XColor = new XColor(my_mc);
	* my_color.setBrightness(50);
	* </code></pre>
	*/
	public function setBrightness (bright:Number):Void {
		ColorUtil.setBrightness(this, bright);
	}
	
	/**
	* Returns the brightness of an XColor object.
	* 
	* @return	The brightness value.
	* 
	* @usage
	* <pre><code>
	* var my_color:XColor = new XColor(my_mc);
	* my_color.setBrightness(50);
	* trace (my_color.getBrightness());
	* </code></pre>
	*/
	public function getBrightness ():Number {
		return ColorUtil.getBrightness(this);
	}
	
	/**
	* Pushes an XColor object towards black or white by an absolute amount.
	* 
	* @param	offset	A number between -255 and 255. Positive values push colors towards white; negative values towards black.
	* 
	* @usage
	* <pre><code>
	* var my_color:XColor = new XColor(my_mc);
	* my_color.setBrightOffset(140);
	* </code></pre>
	*/
	public function setBrightOffset (offset:Number):Void {
		ColorUtil.setBrightOffset(this, offset);
	}
	
	/**
	* Returns the brightness offset value of an XColor object.
	* 
	* @return	The brightness offset value.
	* 
	* @usage
	* <pre><code>
	* var my_color:XColor = new XColor(my_mc);
	* my_color.setBrightOffset(140);
	* trace (my_color.getBrightOffset());
	* </code></pre>
	*/
	public function getBrightOffset ():Number {
		return ColorUtil.getBrightOffset(this);
	}
	
	/**
	* Tints an XColor object with a color according to a certain percentage.
	* 
	* @param	r		The red color value.
	* @param	g		The green color value.
	* @param	b		The blue color value.
	* @param	percent	The tint percentage.
	* 
	* @usage
	* <pre><code>
	* var my_color:XColor = new XColor(my_mc);
	* my_color.setTint(0, 0, 128, 50);
	* </code></pre>
	*/
	public function setTint (r:Number, g:Number, b:Number, percent:Number):Void {
		ColorUtil.setTint(this, r, g, b, percent);
	}
	
	/**
	* Returns the tint of an XColor object.
	* 
	* @return	The tint value object with r, g, b, and percent properties.
	* 
	* @usage
	* <pre><code>
	* var my_color:XColor = new XColor(my_mc);
	* my_color.setTint(0, 0, 128, 50);
	* var tint:Object = my_color.getTint();
	* trace (tint.r);
	* trace (tint.g);
	* trace (tint.b);
	* trace (tint.percent);
	* </code></pre>
	*/
	public function getTint ():Object {
		return ColorUtil.getTint(this);
	}
	
	/**
	* Tints an XColor object with a color according to a certain percentage.
	* 
	* @param	rgb		The rgb value.
	* @param	percent	The tint percentage.
	* 
	* @usage
	* <pre><code>
	* var my_color:XColor = new XColor(my_mc);
	* my_color.setTint2(0x0000FF, 100);
	* </code></pre>
	*/
	public function setTint2 (rgb:Number, percent:Number):Void {
		ColorUtil.setTint2(this, rgb, percent);
	}
	
	/**
	* Returns the tint of an XColor object.
	* 
	* @return	The tint value object with rgb and percent properties.
	* 
	* @usage
	* <pre><code>
	* var my_color:XColor = new XColor(my_mc);
	* my_color.setTint2(0x0000FF, 100);
	* var tint:Object = my_color.getTint2();
	* trace (tint.rgb);
	* trace (tint.percent);
	* </code></pre>
	*/
	public function getTint2 ():Object {
		return ColorUtil.getTint2(this);
	}
	
	/**
	* Tints an XColor object with a color according to red, green, and blue values.
	* 
	* @param	r		The red color value.
	* @param	g		The green color value.
	* @param	b		The blue color value.
	* 
	* @usage
	* <pre><code>
	* var my_color:XColor = new XColor(my_mc);
	* my_color.setTintOffset(0, 0, 128);
	* </code></pre>
	*/
	public function setTintOffset (r:Number, g:Number, b:Number):Void {
		ColorUtil.setTintOffset(this, r, g, b);
	}
	
	/**
	* Returns the tint offset of an XColor object.
	* 
	* @return	The tint offset value object with r, g, and b properties.
	* 
	* @usage
	* <pre><code>
	* var my_color:XColor = new XColor(my_mc);
	* my_color.setTintOffset(0, 0, 128);
	* var tint:Object = my_color.getTintOffset();
	* trace (tint.r);
	* trace (tint.g);
	* trace (tint.b);
	* </code></pre>
	*/
	public function getTintOffset ():Object {
		return ColorUtil.getTintOffset(this);
	}
	
	/**
	* Tints an XColor object with a color according to an rgb value.
	* 
	* @param	rgb		The rgb value.
	* 
	* @usage
	* <pre><code>
	* var my_color:XColor = new XColor(my_mc);
	* my_color.setTintOffset2(0x000080);
	* </code></pre>
	*/
	public function setTintOffset2 (rgb:Number):Void {
		ColorUtil.setTintOffset2(this, rgb);
	}
	
	/**
	* Returns the tint offset of an XColor object.
	* 
	* @return	The tint offset value object with an rgb properties.
	* 
	* @usage
	* <pre><code>
	* var my_color:XColor = new XColor(my_mc);
	* my_color.setTintOffset2(0x000080);
	* trace (my_color.getTintOffset2());
	* </code></pre>
	*/
	public function getTintOffset2 ():Number {
		return ColorUtil.getTintOffset2(this);
	}
	
	/**
	* Performs a straightforward color inversion.
	* 
	* @usage
	* <pre><code>
	* var my_color:XColor = new XColor(my_mc);
	* my_color.invert();
	* </code></pre>
	*/
	public function invert ():Void {
		ColorUtil.invert(this);
	}
	
	/**
	* Inverts an XColor object by a certain percentage.
	* 
	* @param	percent	The negative percentage.
	* 
	* @usage
	* <pre><code>
	* var my_color:XColor = new XColor(my_mc);
	* my_color.setNegative(60);
	* </code></pre>
	*/
	public function setNegative (percent:Number):Void {
		ColorUtil.setNegative(this, percent);
	}
	
	/**
	* Returns the negative percentage of an XColor object.
	* 
	* @return	The negative percentage.
	* 
	* @usage
	* <pre><code>
	* var my_color:XColor = new XColor(my_mc);
	* my_color.setNegative(60);
	* trace (my_color.getNegative());
	* </code></pre>
	*/
	public function getNegative ():Number {
		return ColorUtil.getNegative(this);
	}
	
	/**
	* Specifies a red color value for an XColor object.
	* 
	* @param	amount	The red color value.
	* 
	* @usage
	* <pre><code>
	* var my_color:XColor = new XColor(my_mc);
	* my_color.setRed(128);
	* </code></pre>
	*/
	public function setRed (amount:Number):Void {
		ColorUtil.setRed(this, amount);
	}
	
	/**
	* Returns the red color value of an XColor object.
	* 
	* @return	The red color value.
	* 
	* @usage
	* <pre><code>
	* var my_color:XColor = new XColor(my_mc);
	* my_color.setRed(128);
	* trace (my_color.getRed());
	* </code></pre>
	*/
	public function getRed ():Number {
		return ColorUtil.getRed(this);
	}
	
	/**
	* Specifies a green color value for an XColor object.
	* 
	* @param	amount	The green color value.
	* 
	* @usage
	* <pre><code>
	* var my_color:XColor = new XColor(my_mc);
	* my_color.setGreen(128);
	* </code></pre>
	*/
	public function setGreen (amount:Number):Void {
		ColorUtil.setGreen(this, amount);
	}
	
	/**
	* Returns the green color value of an XColor object.
	* 
	* @return	The green color value.
	* 
	* @usage
	* <pre><code>
	* var my_color:XColor = new XColor(my_mc);
	* my_color.setGreen(128);
	* trace (my_color.getGreen());
	* </code></pre>
	*/
	public function getGreen ():Number {
		return ColorUtil.getGreen(this);
	}
	
	/**
	* Specifies a blue color value for an XColor object.
	* 
	* @param	amount	The blue color value.
	* 
	* @usage
	* <pre><code>
	* var my_color:XColor = new XColor(my_mc);
	* my_color.setBlue(128);
	* </code></pre>
	*/
	public function setBlue (amount:Number):Void {
		ColorUtil.setBlue(this, amount);
	}
	
	/**
	* Returns the blue color value of an XColor object.
	* 
	* @return	The blue color value.
	* 
	* @usage
	* <pre><code>
	* var my_color:XColor = new XColor(my_mc);
	* my_color.setBlue(128);
	* trace (my_color.getBlue());
	* </code></pre>
	*/
	public function getBlue ():Number {
		return ColorUtil.getBlue(this);
	}
	
	/**
	* Specifies a red percentage value for an XColor object.
	* 
	* @param	percent	The red percentage value.
	* 
	* @usage
	* <pre><code>
	* var my_color:XColor = new XColor(my_mc);
	* my_color.setRedPercent(50);
	* </code></pre>
	*/
	public function setRedPercent (percent:Number):Void {
		ColorUtil.setRedPercent(this, percent);
	}
	
	/**
	* Returns the red percentage value of an XColor object.
	* 
	* @return	The red percentage value.
	* 
	* @usage
	* <pre><code>
	* var my_color:XColor = new XColor(my_mc);
	* my_color.setRedPercent(50);
	* trace (my_color.getRedPercent());
	* </code></pre>
	*/
	public function getRedPercent ():Number {
		return ColorUtil.getRedPercent(this);
	}
	
	/**
	* Specifies a green percentage value for an XColor object.
	* 
	* @param	percent	The green percentage value.
	* 
	* @usage
	* <pre><code>
	* var my_color:XColor = new XColor(my_mc);
	* my_color.setGreenPercent(50);
	* </code></pre>
	*/
	public function setGreenPercent (percent:Number):Void {
		ColorUtil.setGreenPercent(this, percent);
	}
	
	/**
	* Returns the green percentage value of an XColor object.
	* 
	* @return	The green percentage value.
	* 
	* @usage
	* <pre><code>
	* var my_color:XColor = new XColor(my_mc);
	* my_color.setGreenPercent(50);
	* trace (my_color.getGreenPercent());
	* </code></pre>
	*/
	public function getGreenPercent ():Number {
		return ColorUtil.getGreenPercent(this);
	}
	
	/**
	* Specifies a blue percentage value for an XColor object.
	* 
	* @param	percent	The blue percentage value.
	* 
	* @usage
	* <pre><code>
	* var my_color:XColor = new XColor(my_mc);
	* my_color.setBluePercent(50);
	* </code></pre>
	*/
	public function setBluePercent (percent:Number):Void {
		ColorUtil.setBluePercent(this, percent);
	}
	
	/**
	* Returns the blue percentage value of an XColor object.
	* 
	* @return	The blue percentage value.
	* 
	* @usage
	* <pre><code>
	* var my_color:XColor = new XColor(my_mc);
	* my_color.setBluePercent(50);
	* trace (my_color.getBluePercent());
	* </code></pre>
	*/
	public function getBluePercent ():Number {
		return ColorUtil.getBluePercent(this);
	}
	
	/**
	* Specifies a red offset value for an XColor object.
	* 
	* @param	percent	The red offset value.
	* 
	* @usage
	* <pre><code>
	* var my_color:XColor = new XColor(my_mc);
	* my_color.setRedOffset(-128);
	* </code></pre>
	*/
	public function setRedOffset (offset:Number):Void {
		ColorUtil.setRedOffset(this, offset);
	}
	
	/**
	* Returns the red offset value of an XColor object.
	* 
	* @return	The red offset value.
	* 
	* @usage
	* <pre><code>
	* var my_color:XColor = new XColor(my_mc);
	* my_color.setRedOffset(-128);
	* trace (my_color.getRedOffset());
	* </code></pre>
	*/
	public function getRedOffset ():Number {
		return ColorUtil.getRedOffset(this);
	}
	
	/**
	* Specifies a green offset value for an XColor object.
	* 
	* @param	percent	The green offset value.
	* 
	* @usage
	* <pre><code>
	* var my_color:XColor = new XColor(my_mc);
	* my_color.setGreenOffset(-128);
	* </code></pre>
	*/
	public function setGreenOffset (offset:Number):Void {
		ColorUtil.setGreenOffset(this, offset);
	}
	
	/**
	* Returns the green offset value of an XColor object.
	* 
	* @return	The green offset value.
	* 
	* @usage
	* <pre><code>
	* var my_color:XColor = new XColor(my_mc);
	* my_color.setGreenOffset(-128);
	* trace (my_color.getGreenOffset());
	* </code></pre>
	*/
	public function getGreenOffset ():Number {
		return ColorUtil.getGreenOffset(this);
	}
	
	/**
	* Specifies a blue offset value for an XColor object.
	* 
	* @param	percent	The blue offset value.
	* 
	* @usage
	* <pre><code>
	* var my_color:XColor = new XColor(my_mc);
	* my_color.setBlueOffset(-128);
	* </code></pre>
	*/
	public function setBlueOffset (offset:Number):Void {
		ColorUtil.setBlueOffset(this, offset);
	}
	
	/**
	* Returns the blue offset value of an XColor object.
	* 
	* @return	The blue offset value.
	* 
	* @usage
	* <pre><code>
	* var my_color:XColor = new XColor(my_mc);
	* my_color.setBlueOffset(-128);
	* trace (my_color.getBlueOffset());
	* </code></pre>
	*/
	public function getBlueOffset ():Number {
		return ColorUtil.getBlueOffset(this);
	}
	
	
	/*
	* *********************************************************
	* GETTERS/SETTERS
	* *********************************************************
	* 
	*/
	
	/**
	* The rgb property of the XColor object.
	* 
	* @usage
	* <pre><code>
	* trace (my_color.rgb);
	* </code></pre>
	*/
	public function get rgb ():Number {
		return this.getRGB();
	}
	public function set rgb (col:Number):Void {
		this.setRGB(col);
	}
	
	/**
	* The rgbStr property of the XColor object.
	* 
	* @usage
	* <pre><code>
	* trace (my_color.rgbStr);
	* </code></pre>
	*/
	public function get rgbStr ():String {
		return this.getRGBStr();
	}
	public function set rgbStr (hexStr:String):Void {
		this.setRGBStr(hexStr);
	}
	
	/**
	* The brightness property of the XColor object.
	* 
	* @usage
	* <pre><code>
	* trace (my_color.brightness);
	* </code></pre>
	*/
	public function get brightness ():Number {
		return this.getBrightness();
	}
	public function set brightness (bright:Number):Void {
		this.setBrightness(bright);
	}
	
	/**
	* The brightOffset property of the XColor object.
	* 
	* @usage
	* <pre><code>
	* trace (my_color.brightOffset);
	* </code></pre>
	*/
	public function get brightOffset ():Number {
		return this.getBrightOffset();
	}
	public function set brightOffset (offset:Number):Void {
		this.setBrightOffset(offset);
	}
	
	/**
	* The negative property of the XColor object.
	* 
	* @usage
	* <pre><code>
	* trace (my_color.negative);
	* </code></pre>
	*/
	public function get negative ():Number {
		return this.getNegative();
	}
	public function set negative (percent:Number):Void {
		this.setNegative(percent);
	}
	
	/**
	* The red property of the XColor object.
	* 
	* @usage
	* <pre><code>
	* trace (my_color.red);
	* </code></pre>
	*/
	public function get red ():Number {
		return this.getRed();
	}
	public function set red (amount:Number):Void {
		this.setRed(amount);
	}
	
	/**
	* The green property of the XColor object.
	* 
	* @usage
	* <pre><code>
	* trace (my_color.green);
	* </code></pre>
	*/
	public function get green ():Number {
		return this.getGreen();
	}
	public function set green (amount:Number):Void {
		this.setGreen(amount);
	}
	
	/**
	* The blue property of the XColor object.
	* 
	* @usage
	* <pre><code>
	* trace (my_color.blue);
	* </code></pre>
	*/
	public function get blue ():Number {
		return this.getBlue();
	}
	public function set blue (amount:Number):Void {
		this.setBlue(amount);
	}
	
	/**
	* The redPercent property of the XColor object.
	* 
	* @usage
	* <pre><code>
	* trace (my_color.redPercent);
	* </code></pre>
	*/
	public function get redPercent ():Number {
		return this.getRedPercent();
	}
	public function set redPercent (percent:Number):Void {
		this.setRedPercent(percent);
	}
	
	/**
	* The greenPercent property of the XColor object.
	* 
	* @usage
	* <pre><code>
	* trace (my_color.greenPercent);
	* </code></pre>
	*/
	public function get greenPercent ():Number {
		return this.getGreenPercent();
	}
	public function set greenPercent (percent:Number):Void {
		this.setGreenPercent(percent);
	}
	
	/**
	* The bluePercent property of the XColor object.
	* 
	* @usage
	* <pre><code>
	* trace (my_color.bluePercent);
	* </code></pre>
	*/
	public function get bluePercent ():Number {
		return this.getBluePercent();
	}
	public function set bluePercent (percent:Number):Void {
		this.setBluePercent(percent);
	}
	
	/**
	* The redOffset property of the XColor object.
	* 
	* @usage
	* <pre><code>
	* trace (my_color.redOffset);
	* </code></pre>
	*/
	public function get redOffset ():Number {
		return this.getRedOffset();
	}
	public function set redOffset (offset:Number):Void {
		this.setRedOffset(offset);
	}
	
	/**
	* The greenOffset property of the XColor object.
	* 
	* @usage
	* <pre><code>
	* trace (my_color.greenOffset);
	* </code></pre>
	*/
	public function get greenOffset ():Number {
		return this.getGreenOffset();
	}
	public function set greenOffset (offset:Number):Void {
		this.setGreenOffset(offset);
	}
	
	/**
	* The blueOffset property of the XColor object.
	* 
	* @usage
	* <pre><code>
	* trace (my_color.blueOffset);
	* </code></pre>
	*/
	public function get blueOffset ():Number {
		return this.getBlueOffset();
	}
	public function set blueOffset (offset:Number):Void {
		this.setBlueOffset(offset);
	}
	
}
