﻿import flash.geom.ColorTransform;
import com.robertpenner.utils.ColorTransformUtil;

/**
* The XColorTransform class extends the ColorTransform class adding a collection of utilities
* that allows for more intuitive color manipulation.
* 
* @author Mark Walters
* © 2006 DigitalFlipbook
* © 2006 DigitalFlipbook
* http://www.digitalflipbook.com
* 
* Based on work by Robert Penner for the Color class.
* © 2002 Robert Penner
* http://www.robertpenner.com
* 
* @version	1.0
* 
* @since	ActionScript 2.0; Flash Player 8
*/
class com.robertpenner.graphics.XColorTransform extends ColorTransform {
	
	/*
	* CLASS PROPERTIES
	*/
	
	/**
	* The rgb property of the XColorTransform object.
	* 
	* @usage
	* <pre><code>
	* trace (my_colorTrans.rgb);
	* </code></pre>
	*/
	public var rgb:Number;
	
	/**
	* The redOffset property of the XColorTransform object.
	* 
	* @usage
	* <pre><code>
	* trace (my_colorTrans.redOffset);
	* </code></pre>
	*/
	public var redOffset:Number;
	
	/**
	* The greenOffset property of the XColorTransform object.
	* 
	* @usage
	* <pre><code>
	* trace (my_colorTrans.greenOffset);
	* </code></pre>
	*/
	public var greenOffset:Number;
	
	/**
	* The blueOffset property of the XColorTransform object.
	* 
	* @usage
	* <pre><code>
	* trace (my_colorTrans.blueOffset);
	* </code></pre>
	*/
	public var blueOffset:Number;
	
	/**
	* The alphaOffset property of the XColorTransform object.
	* 
	* @usage
	* <pre><code>
	* trace (my_colorTrans.alphaOffset);
	* </code></pre>
	*/
	public var alphaOffset:Number;
	
	/**
	* The redMultiplier property of the XColorTransform object.
	* 
	* @usage
	* <pre><code>
	* trace (my_colorTrans.redMultiplier);
	* </code></pre>
	*/
	public var redMultiplier:Number;
	
	/**
	* The greenMultiplier property of the XColorTransform object.
	* 
	* @usage
	* <pre><code>
	* trace (my_colorTrans.greenMultiplier);
	* </code></pre>
	*/
	public var greenMultiplier:Number;
	
	/**
	* The blueMultiplier property of the XColorTransform object.
	* 
	* @usage
	* <pre><code>
	* trace (my_colorTrans.blueMultiplier);
	* </code></pre>
	*/
	public var blueMultiplier:Number;
	
	/**
	* The alphaMultiplier property of the XColorTransform object.
	* 
	* @usage
	* <pre><code>
	* trace (my_colorTrans.alphaMultiplier);
	* </code></pre>
	*/
	public var alphaMultiplier:Number;
	
	/*
	* *********************************************************
	* CONSTRUCTOR
	* *********************************************************
	*
	*/
	function XColorTransform (rm:Number, gm:Number, bm:Number, am:Number, ro:Number, go:Number, bo:Number, ao:Number) {
		super(rm?rm:1, gm?gm:1, bm?bm:1, am?am:1, ro?ro:0, go?go:0, bo?bo:0, ao?ao:0);
	}
	
	
	/*
	* *********************************************************
	* PUBLIC METHODS
	* *********************************************************
	* 
	*/
	
	/**
	* Specifies an RGB color for an XColorTransform object using a string hexadecimal value.
	* 
	* @param	hexStr	The string hexadecimal color to be set.
	* 
	* @usage
	* <pre><code>
	* var my_colorTrans:XColorTransform = new XColorTransform();
	* var my_trans:Transform = new Transform(my_mc);
	* my_colorTrans.setRGBStr("#FFFF00");
	* my_trans.colorTransform = my_colorTrans;
	* </code></pre>
	*/
	public function setRGBStr (hexStr:String):Void {
		ColorTransformUtil.setRGBStr(this, hexStr);
	}
	
	/**
	* Returns the R+G+B combination currently in use by the XColorTransform object as a string hexadecimal value.
	* 
	* @return	The string hexadecimal color.
	* 
	* @usage
	* <pre><code>
	* var my_colorTrans:XColorTransform = new XColorTransform();
	* var my_trans:Transform = new Transform(my_mc);
	* trace (my_colorTrans.getRGBStr());
	* </code></pre>
	*/
	public function getRGBStr ():String {
		return ColorTransformUtil.getRGBStr(this);
	}
	
	/**
	* Specifies an RGB color for an XColorTransform object using individual red, green, and blue values.
	* 
	* @param	r		The red color value.
	* @param	g		The green color value.
	* @param	b		The blue color value.
	* 
	* @usage
	* <pre><code>
	* var my_colorTrans:XColorTransform = new XColorTransform();
	* var my_trans:Transform = new Transform(my_mc);
	* my_colorTrans.setRGB2(255, 0, 255);
	* my_trans.colorTransform = my_colorTrans;
	* </code></pre>
	*/
	public function setRGB2 (r:Number, g:Number, b:Number):Void {
		ColorTransformUtil.setRGB2(this, r, g, b);
	}
	
	/**
	* Returns the R+G+B values currently in use by the XColorTransform object as individual red, green, and blue values.
	* 
	* @return	The RBG value object with r, g, and b properties.
	* 
	* @usage
	* <pre><code>
	* var my_colorTrans:XColorTransform = new XColorTransform();
	* var my_trans:Transform = new Transform(my_mc);
	* my_colorTrans.setRGB2(255, 0, 255);
	* my_trans.colorTransform = my_colorTrans;
	* var rgb:Object = my_colorTrans.getRGB2();
	* trace (rgb.r);
	* trace (rgb.g);
	* trace (rgb.b);
	* </code></pre>
	*/
	public function getRGB2 ():Object {
		return ColorTransformUtil.getRGB2(this);
	}
	
	/**
	* Sets the color transform for an XColorTransform object to its default values.
	* 
	* @usage
	* <pre><code>
	* var my_colorTrans:XColorTransform = new XColorTransform();
	* var my_trans:Transform = new Transform(my_mc);
	* my_colorTrans.rgb = 0x0000FF;
	* my_trans.colorTransform = my_colorTrans;
	* my_colorTrans.reset();
	* my_trans.colorTransform = my_colorTrans;
	* </code></pre>
	*/
	public function reset ():Void {
		ColorTransformUtil.reset(this);
	}
	
	/**
	* Specifies the brightness of an XColorTransform object.
	* 
	* @param	bright	A percentage value between -100 and 100. Positive values brighten the color. and negative values darken it.
	* 
	* @usage
	* <pre><code>
	* var my_colorTrans:XColorTransform = new XColorTransform();
	* var my_trans:Transform = new Transform(my_mc);
	* my_colorTrans.setBrightness(50);
	* my_trans.colorTransform = my_colorTrans;
	* </code></pre>
	*/
	public function setBrightness (bright:Number):Void {
		ColorTransformUtil.setBrightness(this, bright);
	}
	
	/**
	* Returns the brightness of an XColorTransform object.
	* 
	* @return	The brightness value.
	* 
	* @usage
	* <pre><code>
	* var my_colorTrans:XColorTransform = new XColorTransform();
	* var my_trans:Transform = new Transform(my_mc);
	* my_colorTrans.setBrightness(50);
	* my_trans.colorTransform = my_colorTrans;
	* trace (my_colorTrans.getBrightness());
	* </code></pre>
	*/
	public function getBrightness ():Number {
		return ColorTransformUtil.getBrightness(this);
	}
	
	/**
	* Pushes an XColorTransform object towards black or white by an absolute amount.
	* 
	* @param	offset	A number between -255 and 255. Positive values push colors towards white; negative values towards black.
	* 
	* @usage
	* <pre><code>
	* var my_colorTrans:XColorTransform = new XColorTransform();
	* var my_trans:Transform = new Transform(my_mc);
	* my_colorTrans.setBrightOffset(140);
	* my_trans.colorTransform = my_colorTrans;
	* </code></pre>
	*/
	public function setBrightOffset (offset:Number):Void {
		ColorTransformUtil.setBrightOffset(this, offset);
	}
	
	/**
	* Returns the brightness offset value of an XColorTransform object.
	* 
	* @return	The brightness offset value.
	* 
	* @usage
	* <pre><code>
	* var my_colorTrans:XColorTransform = new XColorTransform();
	* var my_trans:Transform = new Transform(my_mc);
	* my_colorTrans.setBrightOffset(140);
	* my_trans.colorTransform = my_colorTrans;
	* trace (my_colorTrans.getBrightOffset());
	* </code></pre>
	*/
	public function getBrightOffset ():Number {
		return ColorTransformUtil.getBrightOffset(this);
	}
	
	/**
	* Tints an XColorTransform object with a color according to a certain percentage.
	* 
	* @param	r		The red color value.
	* @param	g		The green color value.
	* @param	b		The blue color value.
	* @param	percent	The tint percentage.
	* 
	* @usage
	* <pre><code>
	* var my_colorTrans:XColorTransform = new XColorTransform();
	* var my_trans:Transform = new Transform(my_mc);
	* my_colorTrans.setTint(0, 0, 128, 50);
	* my_trans.colorTransform = my_colorTrans;
	* </code></pre>
	*/
	public function setTint (r:Number, g:Number, b:Number, percent:Number):Void {
		ColorTransformUtil.setTint(this, r, g, b, percent);
	}
	
	/**
	* Returns the tint of an XColorTransform object.
	* 
	* @return	The tint value object with r, g, b, and percent properties.
	* 
	* @usage
	* <pre><code>
	* var my_colorTrans:XColorTransform = new XColorTransform();
	* var my_trans:Transform = new Transform(my_mc);
	* my_colorTrans.setTint(0, 0, 128, 50);
	* my_trans.colorTransform = my_colorTrans;
	* var tint:Object = my_colorTrans.getTint();
	* trace (tint.r);
	* trace (tint.g);
	* trace (tint.b);
	* trace (tint.percent);
	* </code></pre>
	*/
	public function getTint ():Object {
		return ColorTransformUtil.getTint(this);
	}
	
	/**
	* Tints an XColorTransform object with a color according to a certain percentage.
	* 
	* @param	rgb		The rgb value.
	* @param	percent	The tint percentage.
	* 
	* @usage
	* <pre><code>
	* var my_colorTrans:XColorTransform = new XColorTransform();
	* var my_trans:Transform = new Transform(my_mc);
	* my_colorTrans.setTint2(0x0000FF, 100);
	* my_trans.colorTransform = my_colorTrans;
	* </code></pre>
	*/
	public function setTint2 (rgb:Number, percent:Number):Void {
		ColorTransformUtil.setTint2(this, rgb, percent);
	}
	
	/**
	* Returns the tint of an XColorTransform object.
	* 
	* @return	The tint value object with rgb and percent properties.
	* 
	* @usage
	* <pre><code>
	* var my_colorTrans:XColorTransform = new XColorTransform();
	* var my_trans:Transform = new Transform(my_mc);
	* my_colorTrans.setTint2(0x0000FF, 100);
	* my_trans.colorTransform = my_colorTrans;
	* var tint:Object = my_colorTrans.getTint2();
	* trace (tint.rgb);
	* trace (tint.percent);
	* </code></pre>
	*/
	public function getTint2 ():Object {
		return ColorTransformUtil.getTint2(this);
	}
	
	/**
	* Tints an XColorTransform object with a color according to red, green, and blue values.
	* 
	* @param	r		The red color value.
	* @param	g		The green color value.
	* @param	b		The blue color value.
	* 
	* @usage
	* <pre><code>
	* var my_colorTrans:XColorTransform = new XColorTransform();
	* var my_trans:Transform = new Transform(my_mc);
	* my_colorTrans.setTintOffset(0, 0, 128);
	* my_trans.colorTransform = my_colorTrans;
	* </code></pre>
	*/
	public function setTintOffset (r:Number, g:Number, b:Number):Void {
		ColorTransformUtil.setTintOffset(this, r, g, b);
	}
	
	/**
	* Returns the tint offset of an XColorTransform object.
	* 
	* @return	The tint offset value object with r, g, and b properties.
	* 
	* @usage
	* <pre><code>
	* var my_colorTrans:XColorTransform = new XColorTransform();
	* var my_trans:Transform = new Transform(my_mc);
	* my_colorTrans.setTintOffset(0, 0, 128);
	* my_trans.colorTransform = my_colorTrans;
	* var tint:Object = my_colorTrans.getTintOffset();
	* trace (tint.r);
	* trace (tint.g);
	* trace (tint.b);
	* </code></pre>
	*/
	public function getTintOffset ():Object {
		return ColorTransformUtil.getTintOffset(this);
	}
	
	/**
	* Tints an XColorTransform object with a color according to an rgb value.
	* 
	* @param	rgb		The rgb value.
	* 
	* @usage
	* <pre><code>
	* var my_colorTrans:XColorTransform = new XColorTransform();
	* var my_trans:Transform = new Transform(my_mc);
	* my_colorTrans.setTintOffset2(0x000080);
	* my_trans.colorTransform = my_colorTrans;
	* </code></pre>
	*/
	public function setTintOffset2 (rgb:Number):Void {
		ColorTransformUtil.setTintOffset2(this, rgb);
	}
	
	/**
	* Returns the tint offset of an XColorTransform object.
	* 
	* @return	The tint offset value object with an rgb properties.
	* 
	* @usage
	* <pre><code>
	* var my_colorTrans:XColorTransform = new XColorTransform();
	* var my_trans:Transform = new Transform(my_mc);
	* my_colorTrans.setTintOffset2(0x000080);
	* my_trans.colorTransform = my_colorTrans;
	* trace (my_colorTrans.getTintOffset2());
	* </code></pre>
	*/
	public function getTintOffset2 ():Number {
		return ColorTransformUtil.getTintOffset2(this);
	}
	
	/**
	* Performs a straightforward color inversion.
	* 
	* @usage
	* <pre><code>
	* var my_colorTrans:XColorTransform = new XColorTransform();
	* var my_trans:Transform = new Transform(my_mc);
	* my_colorTrans.invert();
	* my_trans.colorTransform = my_colorTrans;
	* </code></pre>
	*/
	public function invert ():Void {
		ColorTransformUtil.invert(this);
	}
	
	/**
	* Inverts an XColorTransform object by a certain percentage.
	* 
	* @param	percent	The negative percentage.
	* 
	* @usage
	* <pre><code>
	* var my_colorTrans:XColorTransform = new XColorTransform();
	* var my_trans:Transform = new Transform(my_mc);
	* my_colorTrans.setNegative(60);
	* my_trans.colorTransform = my_colorTrans;
	* </code></pre>
	*/
	public function setNegative (percent:Number):Void {
		ColorTransformUtil.setNegative(this, percent);
	}
	
	/**
	* Returns the negative percentage of an XColorTransform object.
	* 
	* @return	The negative percentage.
	* 
	* @usage
	* <pre><code>
	* var my_colorTrans:XColorTransform = new XColorTransform();
	* var my_trans:Transform = new Transform(my_mc);
	* my_colorTrans.setNegative(60);
	* my_trans.colorTransform = my_colorTrans;
	* trace (my_colorTrans.getNegative());
	* </code></pre>
	*/
	public function getNegative ():Number {
		return ColorTransformUtil.getNegative(this);
	}
	
	/**
	* Specifies a red color value for an XColorTransform object.
	* 
	* @param	amount	The red color value.
	* 
	* @usage
	* <pre><code>
	* var my_colorTrans:XColorTransform = new XColorTransform();
	* var my_trans:Transform = new Transform(my_mc);
	* my_colorTrans.setRed(128);
	* my_trans.colorTransform = my_colorTrans;
	* </code></pre>
	*/
	public function setRed (amount:Number):Void {
		ColorTransformUtil.setRed(this, amount);
	}
	
	/**
	* Returns the red color value of an XColorTransform object.
	* 
	* @return	The red color value.
	* 
	* @usage
	* <pre><code>
	* var my_colorTrans:XColorTransform = new XColorTransform();
	* var my_trans:Transform = new Transform(my_mc);
	* my_colorTrans.setRed(128);
	* my_trans.colorTransform = my_colorTrans;
	* trace (my_colorTrans.getRed());
	* </code></pre>
	*/
	public function getRed ():Number {
		return ColorTransformUtil.getRed(this);
	}
	
	/**
	* Specifies a green color value for an XColorTransform object.
	* 
	* @param	amount	The green color value.
	* 
	* @usage
	* <pre><code>
	* var my_colorTrans:XColorTransform = new XColorTransform();
	* var my_trans:Transform = new Transform(my_mc);
	* my_colorTrans.setGreen(128);
	* my_trans.colorTransform = my_colorTrans;
	* </code></pre>
	*/
	public function setGreen (amount:Number):Void {
		ColorTransformUtil.setGreen(this, amount);
	}
	
	/**
	* Returns the green color value of an XColorTransform object.
	* 
	* @return	The green color value.
	* 
	* @usage
	* <pre><code>
	* var my_colorTrans:XColorTransform = new XColorTransform();
	* var my_trans:Transform = new Transform(my_mc);
	* my_colorTrans.setGreen(128);
	* my_trans.colorTransform = my_colorTrans;
	* trace (my_colorTrans.getGreen());
	* </code></pre>
	*/
	public function getGreen ():Number {
		return ColorTransformUtil.getGreen(this);
	}
	
	/**
	* Specifies a blue color value for an XColorTransform object.
	* 
	* @param	amount	The blue color value.
	* 
	* @usage
	* <pre><code>
	* var my_colorTrans:XColorTransform = new XColorTransform();
	* var my_trans:Transform = new Transform(my_mc);
	* my_colorTrans.setBlue(128);
	* my_trans.colorTransform = my_colorTrans;
	* </code></pre>
	*/
	public function setBlue (amount:Number):Void {
		ColorTransformUtil.setBlue(this, amount);
	}
	
	/**
	* Returns the blue color value of an XColorTransform object.
	* 
	* @return	The blue color value.
	* 
	* @usage
	* <pre><code>
	* var my_colorTrans:XColorTransform = new XColorTransform();
	* var my_trans:Transform = new Transform(my_mc);
	* my_colorTrans.setBlue(128);
	* my_trans.colorTransform = my_colorTrans;
	* trace (my_colorTrans.getBlue());
	* </code></pre>
	*/
	public function getBlue ():Number {
		return ColorTransformUtil.getBlue(this);
	}
	
	/**
	* Specifies a red percentage value for an XColorTransform object.
	* 
	* @param	percent	The red percentage value.
	* 
	* @usage
	* <pre><code>
	* var my_colorTrans:XColorTransform = new XColorTransform();
	* var my_trans:Transform = new Transform(my_mc);
	* my_colorTrans.setRedPercent(50);
	* my_trans.colorTransform = my_colorTrans;
	* </code></pre>
	*/
	public function setRedPercent (percent:Number):Void {
		ColorTransformUtil.setRedPercent(this, percent);
	}
	
	/**
	* Returns the red percentage value of an XColorTransform object.
	* 
	* @return	The red percentage value.
	* 
	* @usage
	* <pre><code>
	* var my_colorTrans:XColorTransform = new XColorTransform();
	* var my_trans:Transform = new Transform(my_mc);
	* my_colorTrans.setRedPercent(50);
	* my_trans.colorTransform = my_colorTrans;
	* trace (my_colorTrans.getRedPercent());
	* </code></pre>
	*/
	public function getRedPercent ():Number {
		return ColorTransformUtil.getRedPercent(this);
	}
	
	/**
	* Specifies a green percentage value for an XColorTransform object.
	* 
	* @param	percent	The green percentage value.
	* 
	* @usage
	* <pre><code>
	* var my_colorTrans:XColorTransform = new XColorTransform();
	* var my_trans:Transform = new Transform(my_mc);
	* my_colorTrans.setGreenPercent(50);
	* my_trans.colorTransform = my_colorTrans;
	* </code></pre>
	*/
	public function setGreenPercent (percent:Number):Void {
		ColorTransformUtil.setGreenPercent(this, percent);
	}
	
	/**
	* Returns the green percentage value of an XColorTransform object.
	* 
	* @return	The green percentage value.
	* 
	* @usage
	* <pre><code>
	* var my_colorTrans:XColorTransform = new XColorTransform();
	* var my_trans:Transform = new Transform(my_mc);
	* my_colorTrans.setGreenPercent(50);
	* my_trans.colorTransform = my_colorTrans;
	* trace (my_colorTrans.getGreenPercent());
	* </code></pre>
	*/
	public function getGreenPercent ():Number {
		return ColorTransformUtil.getGreenPercent(this);
	}
	
	/**
	* Specifies a blue percentage value for an XColorTransform object.
	* 
	* @param	percent	The blue percentage value.
	* 
	* @usage
	* <pre><code>
	* var my_colorTrans:XColorTransform = new XColorTransform();
	* var my_trans:Transform = new Transform(my_mc);
	* my_colorTrans.setBluePercent(50);
	* my_trans.colorTransform = my_colorTrans;
	* </code></pre>
	*/
	public function setBluePercent (percent:Number):Void {
		ColorTransformUtil.setBluePercent(this, percent);
	}
	
	/**
	* Returns the blue percentage value of an XColorTransform object.
	* 
	* @return	The blue percentage value.
	* 
	* @usage
	* <pre><code>
	* var my_colorTrans:XColorTransform = new XColorTransform();
	* var my_trans:Transform = new Transform(my_mc);
	* my_colorTrans.setBluePercent(50);
	* my_trans.colorTransform = my_colorTrans;
	* trace (my_colorTrans.getBluePercent());
	* </code></pre>
	*/
	public function getBluePercent ():Number {
		return ColorTransformUtil.getBluePercent(this);
	}
	
	/**
	* Formats and returns a string that describes all of the properties of the XColorTransform object.
	* 
	* @return	A string that lists all of the properties of the XColorTransform object.
	* 
	* @usage
	* <pre><code>
	* var my_colorTrans:XColorTransform = new XColorTransform(1, 2, 3, 4, -255, -128, 128, 255);
	* trace(my_colorTrans.toString());
	* </code></pre>
	*/
	public function toString():String {
		return super.toString();
	}
	
	/**
	* Applies a second, additive color transformation to the movie clip.
	* 
	* @param	second	A second ColorTransform object to be combined with the current XColorTransform object.
	* 
	* @usage
	* <pre><code>
	* var colorTrans_1:XColorTransform = new XColorTransform(1, 1, 1, 1, 255, 0, 0, 0);
	* var colorTrans_2:XColorTransform = new XColorTransform(1, 1, 1, .5, 0, 0, 0, 0);
	* colorTrans_1.concat(colorTrans_2);
	* var my_trans:Transform = new Transform(my_mc);
	* my_trans.colorTransform = colorTrans_1;
	* </code></pre>
	*/
	public function concat(second:ColorTransform):Void {
		super.concat(second);
	}
	
	
	/*
	* *********************************************************
	* GETTERS/SETTERS
	* *********************************************************
	* 
	*/
	
	/**
	* The rgbStr property of the XColorTransform object.
	* 
	* @usage
	* <pre><code>
	* trace (my_colorTrans.rgbStr);
	* </code></pre>
	*/
	public function get rgbStr ():String {
		return this.getRGBStr();
	}
	public function set rgbStr (hexStr:String):Void {
		this.setRGBStr(hexStr);
	}
	
	/**
	* The brightness property of the XColorTransform object.
	* 
	* @usage
	* <pre><code>
	* trace (my_colorTrans.brightness);
	* </code></pre>
	*/
	public function get brightness ():Number {
		return this.getBrightness();
	}
	public function set brightness (bright:Number):Void {
		this.setBrightness(bright);
	}
	
	/**
	* The brightOffset property of the XColorTransform object.
	* 
	* @usage
	* <pre><code>
	* trace (my_colorTrans.brightOffset);
	* </code></pre>
	*/
	public function get brightOffset ():Number {
		return this.getBrightOffset();
	}
	public function set brightOffset (offset:Number):Void {
		this.setBrightOffset(offset);
	}
	
	/**
	* The negative property of the XColorTransform object.
	* 
	* @usage
	* <pre><code>
	* trace (my_colorTrans.negative);
	* </code></pre>
	*/
	public function get negative ():Number {
		return this.getNegative();
	}
	public function set negative (percent:Number):Void {
		this.setNegative(percent);
	}
	
	/**
	* The red property of the XColorTransform object.
	* 
	* @usage
	* <pre><code>
	* trace (my_colorTrans.red);
	* </code></pre>
	*/
	public function get red ():Number {
		return this.getRed();
	}
	public function set red (amount:Number):Void {
		this.setRed(amount);
	}
	
	/**
	* The green property of the XColorTransform object.
	* 
	* @usage
	* <pre><code>
	* trace (my_colorTrans.green);
	* </code></pre>
	*/
	public function get green ():Number {
		return this.getGreen();
	}
	public function set green (amount:Number):Void {
		this.setGreen(amount);
	}
	
	/**
	* The blue property of the XColorTransform object.
	* 
	* @usage
	* <pre><code>
	* trace (my_colorTrans.blue);
	* </code></pre>
	*/
	public function get blue ():Number {
		return this.getBlue();
	}
	public function set blue (amount:Number):Void {
		this.setBlue(amount);
	}
	
	/**
	* The redPercent property of the XColorTransform object.
	* 
	* @usage
	* <pre><code>
	* trace (my_colorTrans.redPercent);
	* </code></pre>
	*/
	public function get redPercent ():Number {
		return this.getRedPercent();
	}
	public function set redPercent (percent:Number):Void {
		this.setRedPercent(percent);
	}
	
	/**
	* The greenPercent property of the XColorTransform object.
	* 
	* @usage
	* <pre><code>
	* trace (my_colorTrans.greenPercent);
	* </code></pre>
	*/
	public function get greenPercent ():Number {
		return this.getGreenPercent();
	}
	public function set greenPercent (percent:Number):Void {
		this.setGreenPercent(percent);
	}
	
	/**
	* The bluePercent property of the XColorTransform object.
	* 
	* @usage
	* <pre><code>
	* trace (my_colorTrans.bluePercent);
	* </code></pre>
	*/
	public function get bluePercent ():Number {
		return this.getBluePercent();
	}
	public function set bluePercent (percent:Number):Void {
		this.setBluePercent(percent);
	}
	
}
